from distutils.core import setup

setup(
    name='wolf_nester',
    version='1.0.0',
    py_modules=['wolf_nester'],
    author='wolf',
    author_email='sunboy_liaobin20@163.com',
    description='A simple printer of nested lists'
)